==> beast-privilege-api-2.9.11-sources.jar: com/thebeastshop/privilege/vo/BirthdayGiftVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * Created by gensheng.ye on 2019/8/5.
 */
public class BirthdayGiftVO implements Serializable {


    private Integer id;
    private String code;
    private String name;
    private String memberLevel;
    private String accessWay;
    private String excludeStores;
    private Date startDate;
    private Date endDate;
    private Integer status;
    private Integer createUserId;
    private String createUserName;
    private Date createTime;
    private Date updateTime;
    private Integer active;
    private List<BirthdayGiftDetailVO> birthdayGiftDetailList;
    private String memberLevelDesc;
    private String accessWayDesc;
    private String statusDesc;
    private String channelCodes;


    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getMemberLevel() {
        return memberLevel;
    }

    public void setMemberLevel(String memberLevel) {
        this.memberLevel = memberLevel;
    }

    public String getAccessWay() {
        return accessWay;
    }

    public void setAccessWay(String accessWay) {
        this.accessWay = accessWay;
    }

    public String getExcludeStores() {
        return excludeStores;
    }

    public void setExcludeStores(String excludeStores) {
        this.excludeStores = excludeStores;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Integer getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Integer createUserId) {
        this.createUserId = createUserId;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public Integer getActive() {
        return active;
    }

    public void setActive(Integer active) {
        this.active = active;
    }

    public List<BirthdayGiftDetailVO> getBirthdayGiftDetailList() {
        return birthdayGiftDetailList;
    }

    public void setBirthdayGiftDetailList(List<BirthdayGiftDetailVO> birthdayGiftDetailList) {
        this.birthdayGiftDetailList = birthdayGiftDetailList;
    }

    public String getMemberLevelDesc() {
        return memberLevelDesc;
    }

    public void setMemberLevelDesc(String memberLevelDesc) {
        this.memberLevelDesc = memberLevelDesc;
    }

    public String getAccessWayDesc() {
        return accessWayDesc;
    }

    public void setAccessWayDesc(String accessWayDesc) {
        this.accessWayDesc = accessWayDesc;
    }

    public String getStatusDesc() {
        return statusDesc;
    }

    public void setStatusDesc(String statusDesc) {
        this.statusDesc = statusDesc;
    }

    public String getChannelCodes() {
        return channelCodes;
    }

    public void setChannelCodes(String channelCodes) {
        this.channelCodes = channelCodes;
    }

}

==> beast-privilege-api-3.0.9-sources.jar: com/thebeastshop/privilege/vo/BirthdayGiftVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * Created by gensheng.ye on 2019/8/5.
 */
public class BirthdayGiftVO implements Serializable {


    private Integer id;
    private String code;
    private String name;
    private String memberLevel;
    private String accessWay;
    private String excludeStores;
    private Date startDate;
    private Date endDate;
    private Integer status;
    private Integer createUserId;
    private String createUserName;
    private Date createTime;
    private Date updateTime;
    private Integer active;
    private List<BirthdayGiftDetailVO> birthdayGiftDetailList;
    private String memberLevelDesc;
    private String accessWayDesc;
    private String statusDesc;
    private String channelCodes;

    private Integer villaTbh;


    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getMemberLevel() {
        return memberLevel;
    }

    public void setMemberLevel(String memberLevel) {
        this.memberLevel = memberLevel;
    }

    public String getAccessWay() {
        return accessWay;
    }

    public void setAccessWay(String accessWay) {
        this.accessWay = accessWay;
    }

    public String getExcludeStores() {
        return excludeStores;
    }

    public void setExcludeStores(String excludeStores) {
        this.excludeStores = excludeStores;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Integer getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Integer createUserId) {
        this.createUserId = createUserId;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public Integer getActive() {
        return active;
    }

    public void setActive(Integer active) {
        this.active = active;
    }

    public List<BirthdayGiftDetailVO> getBirthdayGiftDetailList() {
        return birthdayGiftDetailList;
    }

    public void setBirthdayGiftDetailList(List<BirthdayGiftDetailVO> birthdayGiftDetailList) {
        this.birthdayGiftDetailList = birthdayGiftDetailList;
    }

    public String getMemberLevelDesc() {
        return memberLevelDesc;
    }

    public void setMemberLevelDesc(String memberLevelDesc) {
        this.memberLevelDesc = memberLevelDesc;
    }

    public String getAccessWayDesc() {
        return accessWayDesc;
    }

    public void setAccessWayDesc(String accessWayDesc) {
        this.accessWayDesc = accessWayDesc;
    }

    public String getStatusDesc() {
        return statusDesc;
    }

    public void setStatusDesc(String statusDesc) {
        this.statusDesc = statusDesc;
    }

    public String getChannelCodes() {
        return channelCodes;
    }

    public void setChannelCodes(String channelCodes) {
        this.channelCodes = channelCodes;
    }


    public Integer getVillaTbh() {
        return villaTbh;
    }

    public void setVillaTbh(Integer villaTbh) {
        this.villaTbh = villaTbh;
    }
}
